/*****************************************************************
* Unipro UGENE - Integrated Bioinformatics Suite
* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
* All Rights Reserved
* 
*     This source code is distributed under the terms of the
*     GNU General Public License. See the files COPYING and LICENSE
*     for details.
*****************************************************************/

#ifndef _U2_CHECK_UPDATES_TASKS_H_
#define _U2_CHECK_UPDATES_TASKS_H_

#include <U2Core/Task.h>

namespace U2 {

class CheckUpdatesTask : public Task {
    Q_OBJECT

public:
    CheckUpdatesTask();
    void run();
    ReportResult report();

    QString siteVersion;
};


}//namespace

#endif
